@@ -29,7 +29,7 @@ class VtkWriter
  };
  
 private:
- std::vector<Mesh3*> _vecmesh;
+ std::vector<const Mesh3*> _vecmesh;
  //std::vector<tsinfo> _vecofts;
  std::string _nameoffile;
 
@@ -56,9 +56,9 @@ public:
     }
   }
 
- void addmesh(Mesh3* mesh)
+ void addmesh(const Mesh3* mesh)
   {
-   Mesh3& Th(*mesh);
+   const Mesh3& Th(*mesh);
    _vecmesh.push_back(mesh);
    _ofdata.flags(std::ios_base::scientific);
    _ofdata.precision(15);
@@ -91,7 +91,7 @@ public:
   }
  
  /*!Add a field*/
- void addscalar(const string& nameoffield, Mesh3* mesh, const KN<double>&val)
+ void addscalar(const string& nameoffield,const Mesh3* mesh, const KN<double>&val)
   {
    _ofdata.flags(std::ios_base::scientific);
    _ofdata.precision(15);
@@ -112,7 +112,7 @@ public:
   }
 
   /*!Add a field*/
- void addvector(const string& nameoffield, Mesh3* mesh, const KN<double>&val,
+ void addvector(const string& nameoffield,const Mesh3* mesh, const KN<double>&val,
                 const KN<double>&val2,const KN<double>&val3 )
   {
    _ofdata.flags(std::ios_base::scientific);
@@ -126,7 +126,7 @@ public:
 
 
  /*!Get the mesh associated with the series nameofts*/
- Mesh3* getmeshts(const string& nameofts)
+ const Mesh3* getmeshts(const string& nameofts)
   {
    return _vecmesh[0];
   }
@@ -242,7 +242,7 @@ AnyType Vtkwritesol_Op::operator()(Stack stack)  const
  VtkWriter &dx=*(GetAny<VtkWriter *>((*edx)(stack)));
  string &name=*(GetAny<string *>((*ename)(stack)));
  //double t=GetAny<double>((*et)(stack));
- Mesh3 &Th=*(dx.getmeshts(name));
+ const Mesh3 &Th=*(dx.getmeshts(name));
  
  int nt = Th.nt;
  int nv = Th.nv;
@@ -340,7 +340,7 @@ VtkWriter* init_VtkWriter(VtkWriter * const &a, string * const & s)
  return a;
 } 
 
-void* call_addmesh( VtkWriter * const & mt, Mesh3* const & pTh) {
+void* call_addmesh( VtkWriter * const & mt,const Mesh3* const & pTh) {
   mt->addmesh(pTh);
   return NULL;
 }
@@ -361,7 +361,7 @@ static void Load_Init()
  zzzfff->Add("VtkWriter",atype<VtkWriter*>()); // ajoute le type myType a freefem++ 
  // constructeur  d'un type myType  dans freefem 
  TheOperators->Add("<-", new OneOperator2_<VtkWriter*, VtkWriter* ,string*>(&init_VtkWriter));
- Global.Add("Vtkaddmesh","(",new OneOperator2_<void *, VtkWriter*, Mesh3*>(call_addmesh)); 
+ Global.Add("Vtkaddmesh","(",new OneOperator2_<void *, VtkWriter*,const Mesh3*>(call_addmesh));
  Global.Add("Vtkaddscalar","(",new OneOperatorCode< Vtkwritesol_Op> );
  
 }
