@@ -810,13 +810,13 @@ AnyType yams_Op::operator()(Stack stack)  const
 
 
 
-class Init1 { public:
+/*  class Init1 { public:
   Init1();
 };
 
-LOADINIT(Init1)  //  une variable globale qui serat construite  au chargement dynamique 
+$1 */
 
-Init1::Init1(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freefem++ 
+static void Load_Init(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freefem++ 
   //typedef Mesh3 *pmesh3;
   if(verbosity) cout << " load: freeyams  " << endl;
   
@@ -828,3 +828,4 @@ Init1::Init1(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freef
 #define  WITH_NO_INIT
 #include "msh3.hpp" 
 
+LOADFUNC(Load_Init)
