@@ -414,7 +414,6 @@ AnyType EigenValue::E_EV::operator()(Stack stack)  const
    if(expB)
    pB =  GetAny<Matrice_Creuse<K> *>((*expB)(stack));
   double * residptr=resid? (double*) *resid : 0;
-  cout << " residptr = " << residptr <<endl;
   long  n=0;
   if( pOP1)
       n =pOP1->A->n;
@@ -478,7 +477,7 @@ AnyType EigenValue::E_EV::operator()(Stack stack)  const
     if (n != B.M )
 	serr[err++]="Sorry the colum's number of the secand matrix in EigneValue is wrong.";
 	
-   if(verbosity)
+   if(verbosity && mpirank==0)
    {
     if(sym)
       cout << "Real symmetric eigenvalue problem: A*x - B*x*lambda" << endl;
@@ -562,9 +561,9 @@ AnyType EigenValue::E_EV::operator()(Stack stack)  const
 	      cout << "Number of Arnoldi vectors generated: " << ncv  << endl;
 	      cout << "Number of iterations taken         : " << iparam[3]  << endl;
 	      cout << endl;
-	      
+              nconv = min(nconv,nbev);
 	      //if (prob.EigenvaluesFound()) {
-	      cout << "Eigenvalues:" << endl;
+	      cout << "Eigenvalues:" << endl;// Add FH feb 2016
 	      for (int i=0; i<nconv; i++) {
 		cout << "  lambda[" << (i+1) << "]: " << evr(i) << endl;
 		  KN_<K> vi(Z(':',i)) ;
@@ -681,7 +680,8 @@ AnyType EigenValue::E_EV::operator()(Stack stack)  const
 		cout << "Number of Arnoldi vectors generated: " << ncv  << endl;
 		cout << "Number of iterations taken         : " << iparam[3] << endl;
 		cout << endl;
-		  
+                nconv = min(nconv,nbev);// Add FH feb 2016
+  
 		cout << "Eigenvalues:" << endl;
 		for (int i=0; i<nconv; i++) {
 		  cout << "  lambda[" << (i+1) << "]: " ;
@@ -723,6 +723,7 @@ AnyType EigenValue::E_EV::operator()(Stack stack)  const
 	      {
 		//int k=i;
 		KN_<K> vi(Z(':',i)) ;
+                if(verbosity>2 && mpirank ==0 )
 		cout << "   ------ EV--raw " << vi.min() << " " << vi.max() << endl;
 		(*rawvector)(':',i)=vi;
 	      }
@@ -976,8 +977,8 @@ AnyType EigenValueC::E_EV::operator()(Stack stack)  const
 	  cout << "Number of Arnoldi vectors generated: " << ncv << endl;
 	  cout << "Number of iterations taken         : " << iparam[3]  << endl;
 	  cout << endl;
-	  
-	  cout << "Eigenvalues:" << endl;
+          nconv = min(nconv,nbev);
+	  cout << "Eigenvalues:" << endl;// Add FH feb 2016
 	  for (int i=0; i<nconv; i++) {
 	    cout << "  lambda[" << (i+1) << "]: " << evc(i) << endl;
 	    KN_<K> vi(Z(':',i)) ;
@@ -1017,6 +1018,7 @@ AnyType EigenValueC::E_EV::operator()(Stack stack)  const
 		{
 		  KN_<K> vi(Z(':',i)) ;
 		  (*rawvector)(':',i)=vi;
+                   if(verbosity>2 && mpirank ==0 )
 		    cout << " raw " << vi.l2() << " == " << (*rawvector)(':',i).l2()<< endl;
 		}
 	      
@@ -1036,7 +1038,9 @@ void init_eigenvalue()
     Global.Add("EigenValue","(",new EigenValueC());  //  j + dJ
     Global.Add("EigenValue","(",new EigenValue(1));  //  j + dJ
     Global.Add("EigenValue","(",new EigenValue(1,1));  //  j + dJ
-   // Global.Add("EigenValue","(",new EigenValueC(1));  //  j + dJ
+    //  sorry no to solve ambiguity => change of name 
+    Global.Add("complexEigenValue","(",new EigenValueC(1));  //  j + dJ
+    Global.Add("complexEigenValue","(",new EigenValueC(1,1));  //  j + dJ
    
 }
 #else
