@@ -382,6 +382,9 @@ public:
   R lenEdge(int i) const {ASSERTION(i>=0 && i <3);
     Rd E=Edge(i);return sqrt((E,E));}
 
+  R lenEdge2(int i) const {ASSERTION(i>=0 && i <3);
+        Rd E=Edge(i);return ((E,E));}
+  
   R  mesure() const {return mes;}
 
 
@@ -485,6 +488,8 @@ public:
   T & t(int i)  {return elements[CheckT(i)];}
   V & v(int i)  {return vertices[CheckV(i)];}
   B & be(int i) {return borderelements[CheckBE(i)];}
+  const  T & t(int i)  const {return elements[CheckT(i)];}
+  const  V & v(int i)  const {return vertices[CheckV(i)];}
     
     
   GenericMesh()
