@@ -394,7 +394,7 @@ public:
   virtual R * pij(int i,int j) const =0; // Add FH 
   virtual  void  resize(int n,int m)  {AFAIRE("MatriceCreuse::resize");}  // a faire dans les classe derive ... // add march 2009  FH 
   virtual MatriceMorse<R> *toMatriceMorse(bool transpose=false,bool copy=false) const {return 0;} // not 
-  virtual bool addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool trans=false,int ii00=0,int jj00=0,bool cnj=false,double threshold=0.)=0;
+  virtual bool addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool trans=false,int ii00=0,int jj00=0,bool cnj=false,double threshold=0.,const bool keepSym=false)=0;
   // Add FH april 2005
   virtual R pscal(const KN_<R> & x,const KN_<R> & y) =0 ; // produit scalaire  
   virtual double psor(KN_<R> & x,const  KN_<R> & gmin,const  KN_<R> & gmax , double omega) =0;
@@ -409,6 +409,7 @@ public:
    bool ChecknbColumn(int mm) const { return m==mm;} 
 
   // end ADD
+  virtual bool sym() const {return false;}
 
 };
 
@@ -486,8 +487,8 @@ public:
   ~MatriceProfile();
   //  KN_<R>         operator* (const KN_<R> & ) const ;
   void addMatMul(const KN_<R> &x,KN_<R> &ax) const;
-  void addMatTransMul(const KN_<R> &x,KN_<R> &ax) const 
-    { this->t().addMatMul(x,ax);}
+  void addMatTransMul(const KN_<R> &x,KN_<R> &ax) const ;
+  //  { this->t().addMatMul(x,ax);}
   MatriceCreuse<R> & operator +=(MatriceElementaire<R> &);
   void operator=(const R & v); // Mise a zero 
   void cholesky(double = EPSILON/8.) const ; //
@@ -533,7 +534,7 @@ public:
   }
 
   
-  bool addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool trans=false,int ii00=0,int jj00=0,bool cnj=false,double threshold=0.);
+  bool addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool trans=false,int ii00=0,int jj00=0,bool cnj=false,double threshold=0.,const bool keepSym=false);
 
   // Add FH april 2005
   R pscal(const KN_<R> & x,const KN_<R> & y); // produit scalaire  
@@ -668,7 +669,7 @@ template<class K>
  
  MatriceMorse<R> *toMatriceMorse(bool transpose=false,bool copy=false) const {
      return new MatriceMorse(this->n,this->m,nbcoef,symetrique,a,lg,cl,copy, solver,transpose);}
-  bool  addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool trans=false,int ii00=0,int jj00=0,bool cnj=false,double threshold=0.);
+  bool  addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool trans=false,int ii00=0,int jj00=0,bool cnj=false,double threshold=0.,const bool keepSym=false);
   
   template<typename RR,typename K> static  RR CastTo(K  b){return b;}
                                                   
@@ -766,7 +767,7 @@ int ConjuguedGradient2(const M & A,const P & C,KN_<R> &x,const KN_<R> &b,const i
 //  ConjuguedGradient2 affine A*x = 0 est toujours appele avec les condition aux limites 
 //  -------------
     
-   throwassert(&x  && &A && &C);
+  // throwassert(&x  && &A && &C);
    typedef KN<R> Rn;
    int n=x.N();
   // if (verbosity>99) kprint=1;
@@ -911,7 +912,10 @@ struct Data_Sparse_Solver {
   KN<double> scale_c; 
   string sparams;  
   pcommworld commworld;  // pointeur sur le commworld
-    int master; //  master rank in comm add FH 02/2013 for MUMPS ... => VDATASPARSESOLVER exist 
+    int master; //  master rank in comm add FH 02/2013 for MUMPS ... => VDATASPARSESOLVER exist
+    // array for return information for mumps ...
+    KN<double> * rinfo;
+    KN<long> * info;
  /*   
   int *param_int;
   double *param_double;
@@ -959,7 +963,9 @@ struct Data_Sparse_Solver {
      */
     //sparams, 
     commworld(0),
-    master(0)
+    master(0),
+    rinfo(0),
+    info(0)
     {}
     
 private:
