@@ -346,7 +346,7 @@ template<class R>
                 :  make_pair<int,int>(i+ii00,j+jj00) ; }
  
 template<class R>
-bool MatriceProfile<R>::addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool trans,int ii00,int jj00,bool cnj,double threshold)
+bool MatriceProfile<R>::addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool trans,int ii00,int jj00,bool cnj,double threshold, const bool keepSym)
 {
     double eps0=max(numeric_limits<double>::min(), threshold);
     if( RNM::norm2(coef)<eps0) return  L == U ;
@@ -497,6 +497,40 @@ void MatriceProfile<R>::addMatMul(const KN_<R> &x,KN_<R> &ax) const
      }
  
  
+}
+
+template<class R>
+void MatriceProfile<R>::addMatTransMul(const KN_<R> &x,KN_<R> &ax) const
+{if (x.n!= this->n ) ERREUR(MatriceProfile MatMut(xa,x) ," longueur incompatible x (in) ") ;
+    if (ax.n!= this->n ) ERREUR(MatriceProfile MatMut(xa,x) ," longueur incompatible ax (out)") ;
+    int i,j,k,kf;
+    ffassert(this->n == this->m);
+    if (D)
+        for (i=0;i<this->n;i++)
+            ax[i] += RNM::conj(D[i])*x[i];
+    else
+        for (i=0;i<this->n;i++) // no dia => identyty dai
+            ax[i] +=x[i];
+    
+    if (L && pL )
+        for (kf=pL[0],i=0;  i<this->n;   i++  )
+        {
+            k=kf;
+            kf=pL[i+1];
+            for ( j=i-kf+k;   k<kf; j++,  k++  )
+                ax[j] += RNM::conj(L[k])*x[i],throwassert(i>=0 && i <this->n && j >=0 && j < this->m && k>=0 && k < pL[this->n]);
+        }
+    
+    if (U && pU)
+        for (kf=pU[0],j=0;  j<this->m;  j++)
+        {
+            k=kf;
+            kf=pU[j+1];
+            for ( i=j-kf+k;   k<kf; i++,  k++  )
+                ax[j] += RNM::conj(U[k])*x[i],throwassert(i>=0 && i <this->n && j >=0 && j < this->m &&  k>=0 && k < pU[this->n]);
+        }
+    
+    
 }
 
 
@@ -1266,6 +1300,16 @@ template<class R>
     
     int n=0,m=0;
     bool sym=true;
+    for(i=begin;i!=end&&sym;i++++)
+    {
+        if(i->second) // M == 0 => zero matrix 
+        {
+            MatriceCreuse<R> & M=*i->second;
+            if(!M.sym())
+                sym = false;
+        }
+    }
+  
     for(i=begin;i!=end;i++++)
      {
 	if(i->second) // M == 0 => zero matrix 
@@ -1279,11 +1323,10 @@ template<class R>
 	    //  change to max FH dec 2007 to hard to satisfy
 	   /* if (n==0)*/ { if(transpose) {m=max(m,M.n); n=max(n,M.m);} else{n=max(M.n,n); m=max(M.m,m);}}// Modif mars 2007 FH
 	   /* else { if(transpose)  ffassert(n== M.m && m==M.n); else ffassert(n== M.n && m==M.m);}*/
-	    sym = M.addMatTo(coef,mij,transpose,ii00,jj00,transpose&&cnj) && sym;  
+	   M.addMatTo(coef,mij,transpose,ii00,jj00,transpose&&cnj,0.0,sym);
 	}
      } 
     int nbcoef=mij.size();
-    if(sym) nbcoef = (nbcoef+n)/2;
 
   // return new   MatriceMorse<R>(n,m,mij,sym);   
     return make_triplet(n,m,sym);
@@ -1300,7 +1343,7 @@ template<class R>
      
   }
 template<class R>
-bool MatriceMorse<R>::addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool trans,int ii00,int jj00,bool cnj,double threshold)
+bool MatriceMorse<R>::addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool trans,int ii00,int jj00,bool cnj,double threshold, const bool keepSym)
 {
   double eps0=max(numeric_limits<double>::min(),threshold);
   int i,j,k;
@@ -1314,11 +1357,10 @@ bool MatriceMorse<R>::addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool tran
            if(RNM::norm2(cij)>eps0)
            {
             mij[ij_mat(trans,ii00,jj00,i,j)] += cij ;
-           if (i!=j)
+           if (i!=j&&!keepSym)
              mij[ij_mat(trans,ii00,jj00,j,i)] += cij;
            }
          }
-           
    }
   else
    {
@@ -1333,7 +1375,7 @@ bool MatriceMorse<R>::addMatTo(R coef,std::map< pair<int,int>, R> &mij,bool tran
          }
    }
 
-return symetrique;
+return keepSym;
 }
 
  
@@ -1647,9 +1689,9 @@ template<class R>
        for (k=lg[i];k<lg[i+1];k++)
          {
            j=cl[k];
-           ax[j] += a[k]*x[i];
+             ax[j] += RNM::conj(a[k])*x[i];
            if (i!=j)
-             ax[i] += a[k]*x[j];
+             ax[i] += RNM::conj(a[k])*x[j];
          }
            
    }
@@ -1659,7 +1701,7 @@ template<class R>
        for (k=lg[i];k<lg[i+1];k++)
          {
            j=cl[k];
-           ax[j] += a[k]*x[i];
+           ax[j] += RNM::conj(a[k])*x[i];
          }
    }
 }
