@@ -90,6 +90,15 @@ template<class R>
       *l oper (li,u.b); 
     return *this;}
 
+template<class R>
+KN_<R>& KN_<R>::operator oper (const Mul_KNMh_KN_<R> & u)  {
+    K_throwassert (SameShape(u.A.shapei) && !constant());
+    R * l(v); KN_<const_R>  li(u.A(0,'.')); //  first line
+    std::cout << " Mul_KNMh_KN_ "<< endl;
+    for (long i=0;i<n;i++,l += step,++li)
+        *l oper (conj(li),u.b);
+    return *this;}
+
 
 template<class R>
  KN_<R>&  KN_<R>::operator oper (const DotStar_KN_<R> & u) {
