@@ -42,6 +42,9 @@ extern long searchMethod; //pichon
 #include "Serialize.hpp"
 #include "fem.hpp"
 #include <set>
+extern   long npichon2d, npichon3d;
+extern   long npichon2d1, npichon3d1;
+
 namespace Fem2D {
     
     
@@ -986,7 +989,8 @@ int Walk(const Mesh & Th,int& it, R *l,
 }
 const Triangle *  Mesh::Find( R2 P, R2 & Phat,bool & outside,const Triangle * tstart) const
 {
-    int it,j;
+    int CasePichon=0;
+    int it,j,it00;
     const Triangle *  rett=0;
     if ( tstart )
 	it =  (*this)(tstart);
@@ -1002,10 +1006,10 @@ const Triangle *  Mesh::Find( R2 P, R2 & Phat,bool & outside,const Triangle * ts
 	 if (verbosity>100) 
 	 cout << endl << (*this)(v) << *v << " " << Norme2(P-*v) << endl; 
 	 */
-	it=Contening(v);
+	it00=it=Contening(v);
     }
-    
-    //     int itdeb=it;     
+RESTART:
+    //     int itdeb=it;
     //     int count=0;
     //     L1: 
     outside=true; 
@@ -1147,7 +1151,7 @@ const Triangle *  Mesh::Find( R2 P, R2 & Phat,bool & outside,const Triangle * ts
 		return rett;
 	    }
 	    bool ok=false;
-	    // next edge on true boundary 
+	    // next edge on true boundaryS
 	    for (int p=BoundaryAdjacencesHead[ii];p>=0;p=BoundaryAdjacencesLink[p])
 	    { int e=p/2, ie=p%2;// je=2-ie;
 				// cout << number(bedges[e][0]) << " " << number(bedges[e][1]) << endl;
@@ -1162,7 +1166,27 @@ const Triangle *  Mesh::Find( R2 P, R2 & Phat,bool & outside,const Triangle * ts
 	    }
 	    ffassert(ok); 
 	}
-PICHON:	// Add dec 2010 ... 
+PICHON:	// Add dec 2010 ...
+    CasePichon++;
+    if(CasePichon==1) {// hack feb 2016  ..... ???????
+        // change starting triangle  ????
+        R2 PF=(*rett)(Phat);
+        R2 PP=P + (P-PF);
+        const Vertex * v=quadtree->NearestVertexWithNormal(PP);
+        if (!v)
+        {
+            v=quadtree->NearestVertex(P);
+            assert(v);
+        }
+        /*
+         if (verbosity>100)
+         cout << endl << (*this)(v) << *v << " " << Norme2(P-*v) << endl;
+         */
+        it=Contening(v);
+        if( it != it00) goto RESTART;
+    }
+    
+    npichon2d++;
 	// Brute force .... bof bof ...
     double ddp=1e100;
     int pk=-1;
@@ -1574,8 +1598,35 @@ Mesh::Mesh(const Mesh & Th,int * split,bool WithMortar,int label)
 	assert( vertices );
 	
 	nv =0;
-	quadtree = new FQuadTree(this,Pmin,Pmax,nv); //  put all the old vertices in the quadtree 
-						     //  copy of the old vertices 
+	quadtree = new FQuadTree(this,Pmin,Pmax,nv); // build empty the quadtree
+        {  // to keep the order of old vertices to have no problem in
+             // interpolation on sub grid of RT finite element for example (Feb. 2016 F. Hecht)
+        KN<bool> setofv(Th.nv,false);
+        for (int i=0;i<Th.nt;++i)
+          if (split[i])
+              for (int j=0;j<3;++j)
+              setofv[Th(i,j)]=true;
+        for (int i=0;i<Th.nv;++i)
+            if(setofv[i])
+            {
+                Vertex * pV=quadtree->ToClose(Th(i),seuil);
+                if (pV ==0)
+                {
+                 vertices[nv] = Th(i);
+                    if(verbosity>99) cout << " old to new: " << i << " -> " << nv << " / " << Th(i) <<endl;
+                 vertices[nv].normal=0;
+                 quadtree->Add(vertices[nv]);
+                  nv++;
+                }
+
+            }
+            if(verbosity>3)
+            {
+                cout << "  --- number of old vertices use: " << nv << endl;
+                cout << "  --- number of  neb : " << nebmax << endl;
+            }
+        }
+    /*
 	for (int i=0;i<Th.nt;i++)
 	    if (split[i]) 
 		for (int j=0;j<3;j++)
@@ -1595,6 +1646,7 @@ Mesh::Mesh(const Mesh & Th,int * split,bool WithMortar,int label)
 			cout << "  -- number of old vertices use: " << nv << endl;      
 			cout << "  -- number of  neb : " << nebmax << endl;
 		    }
+     */
 	bedges = new BoundaryEdge[nebmax];
 	BoundaryEdge * bedgesi= new BoundaryEdge[nebimax];  // jan 2007 FH
 	int * sdd= new int[Th.nt]; 
