@@ -35,7 +35,7 @@
 //  put here some def dur to c++11 
 // problem with mixed with using namespace std; 
 // to correct bug in g++ v 4.8.1 add std
-#ifdef _WIN32
+#if defined (_WIN32  ) || (__GNUC__ >=5)
 #define NM_STD std::
 #else
 #define NM_STD 
@@ -440,6 +440,14 @@ long exec(string *s)
    operator long () const {return f->precision();}
  };
 
+class OP_setw { public:
+    long w;
+    OP_setw(long ww) :w(ww) {}
+    friend   ostream & operator<<(ostream & f,const OP_setw& op) { return f << setw(op.w);}
+};
+ OP_setw defOP_setw(long i) {return OP_setw(i);}
+
+
  ostream_precis ostream_precision(ostream **f){ return ostream_precis(*f);}
   ostream_precis ostream_precision(ostream *f){ return ostream_precis(f);}
  long get_precis( ostream_precis  pf) { return pf.f->precision();}
@@ -814,8 +822,8 @@ C_F0  formalMatTrace(const basicAC_F0 &args)
     
     
     CC_F0 s;
-    s= A(0,0);
-    for (int i=0;i<na1;++i)
+    s= A(0,0); // correction feb. 2016 Thank to O. Pironneau 
+    for (int i=1;i<na1;++i)
 	s = C_F0(TheOperators,"+",s,A(i,i));
     return  s;
      
@@ -966,6 +974,58 @@ double NaN() {return nan("");}// add march 2012
 int ShowAlloc(const char *s,size_t & lg); 
 long ShowAlloc1(string *  s,long * np) { size_t lg; long  n= ShowAlloc(s->c_str(),lg); *np=lg; return n;}
 long ShowAlloc1(string *  s) { size_t lg; long  n= ShowAlloc(s->c_str(),lg); return n;}
+
+//template<class K,class V,class KK,class VV>
+class E_ForAllLoopMapSS
+{  public:
+    typedef String K;
+    typedef String V;
+    typedef string *KK;
+    typedef string *VV;
+    
+    typedef MyMap<K,V>  *Tab;
+    typedef   MyMap<K,V>::iterator TabI ;
+
+    typedef  ForAllLoopOpBase DataL;
+    const DataL *data;
+    E_ForAllLoopMapSS(const DataL *t): data(t){}
+    AnyType f(Stack s) const {
+        Tab t= GetAny<Tab >(data->tab(s));
+        
+         KK * i   =   GetAny<KK* >(data->i(s));
+         VV * v   =   GetAny<VV* >(data->v(s));
+        if(verbosity>1000) {
+        //      cout << i << " " << j << " " << v << " " << data->epl <<     endl;
+                cout << " i " << (char*) (void *) i -  (char*)(void*) s ;
+        cout << " vi " <<  (char*) (void *) v -  (char*)(void*) s ;
+            cout << endl;}
+        
+        
+        ffassert(i && v);
+        if(t->m)
+        for (TabI ii=t->m->begin();ii != t->m->end();++ii)
+        {
+            String  kk = ii->first;
+            String  vv = ii->second;
+            
+            *i =  kk;
+            *v =  vv;
+           // for  Windows otherwise trap ???? FH. march 2016 
+            if(verbosity>99999) cout << " " << i << " "<< v  << " "  << kk << " " <<  vv << endl;
+
+            data->code(s);
+            
+            ii->second  = **v;
+            *i=0;
+            *v=0;
+            
+        }
+        data->end(s);
+        return Nothing  ;
+    }
+    
+};
+
 void Init_map_type()
 {
    TheOperators=new Polymorphic(), 
@@ -973,7 +1033,7 @@ void Init_map_type()
   //  cout << sizeof(string) << endl;
     map_type[typeid(AnyType).name()] = new ForTypeAnyType();
     map_type[typeid(void).name()] = new ForTypeVoid();
-
+       InitLoop();
     Dcl_Type<Expression>(0);    
     Dcl_TypeandPtr<double>(0,0,::InitializeDef<double>,0);
     Dcl_TypeandPtr<long>(0,0,::InitializeDef<long>,0);
@@ -991,7 +1051,7 @@ void Init_map_type()
     Dcl_Type< istream_seekg > ();
     Dcl_Type< istream_good > ();
     Dcl_Type< NothingType > ();
-    
+    Dcl_Type<OP_setw>();
     Dcl_Type<Polymorphic*>();
     
 //    Dcl_Type<C_F0>();
@@ -1000,7 +1060,10 @@ void Init_map_type()
     Dcl_Type<TransE_Array >();// add
     Dcl_Type<const E_Border *>();
     Dcl_Type<const E_BorderN *>();
-
+    // string[string] type
+    typedef MyMap<String,String> MyMapSS;
+    map_type[typeid(MyMapSS*).name()] = new ForEachType<MyMapSS*>(Initialize<MyMapSS >,Delete<MyMapSS >) ;
+    map_type_of_map[make_pair(atype<string*>(),atype<string*>())]=atype<MyMapSS*>();
     
     
     Dcl_Type<SubArray>();
@@ -1074,7 +1137,9 @@ void Init_map_type()
       
      Global.New("verbosity",CPValue<long>(verbosity));
      Global.New("searchMethod",CPValue<long>(searchMethod)); //pichon
-     
+    extern long newconvect3;// def in global.cpp 
+    Global.New("newconvect",CPValue<long>(newconvect3)); //pichon
+    
      Global.New("cout",CConstant<ostream*>(&cout));
      Global.New("cerr",CConstant<ostream*>(&cerr));// add jan 2014 FH.
      Global.New("cin",CConstant<istream*>(&cin));
@@ -1508,6 +1573,7 @@ void Init_map_type()
      Global.Add("sin","(",new OneOperator1_<Complex>(sin));
      Global.Add("sinh","(",new OneOperator1_<Complex>(sinh));
      Global.Add("cosh","(",new OneOperator1_<Complex>(cosh));
+     Global.Add("tanh","(",new OneOperator1_<Complex>(tanh));// Add June 2016 FH..
      Global.Add("log","(",new OneOperator1_<Complex>(log));
      //     Global.Add("log10","(",new OneOperator1_<Complex>(log10));
      Global.Add("tan","(",new OneOperator1_<Complex>(tan));
@@ -1570,26 +1636,28 @@ void Init_map_type()
   Global.Add("ShowAlloc","(",new OneOperator1<long,string*>(ShowAlloc1));// debuging 
   Global.Add("ShowAlloc","(",new OneOperator2<long,string*,long*>(ShowAlloc1));// debuging 
   Global.Add("NaN","(",new OneOperator0<double>(NaN));
+
   Global.Add("NaN","(",new OneOperator1<double,string*   >(NaN));
     Global.Add("isNaN","(",new OneOperator1<long,double>(isNaN));
     Global.Add("isInf","(",new OneOperator1<long,double>(isInf));
     Global.Add("isNormal","(",new OneOperator1<long,double>(isNormal));
+    Global.Add("chtmpdir","(",new OneOperator0<long>(ffapi::chtmpdir));
  
   
 
-typedef MyMap<String,String> MyMapSS;
-    
-     map_type[typeid(MyMapSS*).name()] = new ForEachType<MyMapSS*>(Initialize<MyMapSS >,Delete<MyMapSS >) ; 
-//Dcl_TypeandPtr_<KN_<string*> ,KN<string*>*  > (0,0,0,::Destroy<KN<K> >, ::ClearReturnKK_<K,KN<K>,KN_<K> >,::ClearReturnpKK<K,KN<K> >);
-    
-  //  map_type[typeid(KN2String*).name()] = new ForEachType<MyMapIS*>(Initialize<KN2String >,Delete<MyMapIS >) ;         
-     map_type_of_map[make_pair(atype<string*>(),atype<string*>())]=atype<MyMapSS*>();      
      atype<MyMapSS*>()->Add("[","",new OneOperator2_<string**,MyMapSS*,string*>(get_elements));
 
+     atype<MyMapSS*>()->SetTypeLoop(atype<string**>(),atype<string**>());
     
           
      tables_of_identifier.push_back(&Global);
-  
+    
+    TheOperators->Add("<<",new OneBinaryOperator<PrintP<MyMapSS*> >);
+ 
+    TheOperators->Add("{}",new ForAllLoop<E_ForAllLoopMapSS >);
+   // add setw freb 2015 FH
+    Global.Add("setw","(",new OneOperator1<OP_setw,long>(defOP_setw));
+    TheOperators->Add("<<", new OneBinaryOperator<Print<OP_setw> >);
 
 }
 //int ShowAlloc(const char *s,size_t & lg); 
