@@ -194,9 +194,9 @@ C_F0::C_F0(const Polymorphic * poly,const char *op,const basicAC_F0 & p)
     if (poly) { // a Polymorphic => polymorphisme
 	const  OneOperator *  ff=poly->Find(op,at);
 	if (ff) { 
-	    /* cout << endl;
+            if( verbosity>9999) {cout << endl;
 	     poly->Show(op,at,cout);
-	     cout << op << ": (in " << at << ") => " << " " << *ff<< "\n\n";*/
+                cout << op << ": (in " << at << ") => " << " " << *ff<< "\n\n";}
 
 	  // [[file:AFunction.hpp::OneOperator_code2]]
 	  *this= ff->code2(p);
@@ -494,7 +494,7 @@ const  Type_Expr &   TableOfIdentifier::New(Key k,const Type_Expr & v,bool del)
     if( this != &Global) {
 	if ( Global.m.find(k) != Global.m.end() )
 	  {
-	    if(mpirank==0) 
+	    if(mpirank==0 && (verbosity>0))
 	      cerr << "\n *** Warning  The identifier " << k << " hide a Global identifier  \n";
 	    
 	  }
@@ -987,3 +987,78 @@ void lgerror (const char* s)
       throw(ErrorCompile(s,zzzfff->lineno(),zzzfff->YYText() ));
   }
 
+
+
+ C_F0 ForAll(Block *cb,ListOfId * id,C_F0  m)
+{
+    
+//Block::open(cb); // new block
+     //  decl variable
+    if(verbosity>1000)
+     cout << "InitAutoLoop ::: " <<  id->size()<< " type=" << *(m.left()) << endl;
+    
+     ffassert(id->size()<4);
+     aType t=m.left() ;
+     ffassert(id->size()<=0 || t->typev);
+     ffassert(id->size()<=1 || t->typei);
+     ffassert(id->size()<=2 || t->typej);
+    // missing this king of code atype<T>->SetTypeLoop(atype<string**>(),atype<K*>())  maybe !!!! FH. 
+     ffassert(id->size()<4);
+     // find the size do data
+     aType tt[4];
+     int k=0;
+     if(t->typei) tt[k++]=t->typei;
+     if(t->typej) tt[k++]=t->typej;
+     if(t->typev) tt[k++]=t->typev;
+    
+     for(int i=0;i<k;++i)
+     {
+     if(verbosity>1000)
+     cout << "     aType = " << i << " left " << *tt[i] << " right="<< *tt[i]->right() <<endl;
+     }
+     AC_F0 args;
+     args=0; // reset
+     args+=m;
+     for(int j=0,i=id->size(); j<id->size() ; ++j)
+     {
+         --i;
+         C_F0 ci=cb->NewVar<LocalVariable>((*id)[i].id,tt[i]);
+         C_F0 cv=Find((*id)[i].id);
+         args+=cv;
+         const LocalVariable *lv = dynamic_cast<LocalVariable*>((E_F0*) cv);
+         if(verbosity>1000)
+         cout << " new id " << tt[i] << " "<< (*id)[i].id << " "  << " E="
+             <<  (Expression)  args[i] << " "
+         <<  (Expression)  ci << " " <<args.size()-1  << " ov: " << (lv ? lv->offset: -1) << " " << *cv.left() << endl;
+     }
+     Expression loop= new PolymorphicLoop(m,args);
+    if(verbosity>1000)
+     cout << "a type: " << *atype<PolymorphicLoop*>() << " " << loop << endl;
+    
+     return C_F0(loop,atype<PolymorphicLoop*>());
+}
+
+ C_F0 ForAll(C_F0  cloop,C_F0  inst,C_F0 end)
+{
+    if(verbosity>1000) 
+    cout << " type cloop " << *cloop.left() << " " << cloop.LeftValue() << " "  << endl;
+    const PolymorphicLoop *loop=  dynamic_cast<const PolymorphicLoop *>(cloop.LeftValue());
+    ffassert(loop);
+    AC_F0 args;
+    args=0;
+    args+=loop->t;
+    args+=cloop;
+    C_F0 instt(inst,atype<NothingType>());
+    C_F0 eend(end,atype<NothingType>());
+    args+=instt;
+    if( (Expression) end !=0)
+      args+=end;
+    return C_F0(TheOperators,"{}",args);
+}
+
+void InitLoop()
+{
+   // TheLoopOpt=new Polymorphic();
+     Dcl_Type<PolymorphicLoop*>(0);
+    
+}
\ No newline at end of file
