@@ -540,6 +540,7 @@ template<class R>  R ** set_copyp_new( R**  a,R*  b){
 
 template<class R>  R ** set_copy_incr( R** const & a, R * const & b){ 
    *a=b;
+    SHOWVERB( cout << "set_copy_incr  " << b << " dans  "<< a << endl);
    if(b) b->increment();
    return a;}
 
@@ -604,8 +605,13 @@ struct Op2_mulpc: public binary_function<A,B,R> {
   static R f(const A & a,const B & b)  { return (b * *a);} }; 
 
 template<class R,class A=R,class B=A> 
-struct Op2_mulpcp: public binary_function<A,B,R> { 
-  static R f(const A & a,const B & b)  { return (*a * *b);} }; 
+struct Op2_mulpcp: public binary_function<A,B,R> {
+  static R f(const A & a,const B & b)  { return (*a * *b);} };
+
+template<class R,class A=R,class B=A>
+struct Op2_2p_: public binary_function<A,B,R> {
+    static R f(const A & a,const B & b)  { return R(*a,*b);} };
+
 
 template<class R,class A=R,class B=A> 
 struct Op2_sub__n: public binary_function<A,B,R*> { 
