@@ -57,14 +57,20 @@ KNM_<double> Get_C2R_(KNM_<complex<double> >  vc)
 void initArrayDCLComplex()
 {
      ArrayDCL<Complex>();
+     Dcl_Type<Mul_KNMh_KN_<Complex> >();
+
 }
 
 Complex square(const Complex & x){return x*x;}
+double imagc(const Complex & x){return imag(x);}
+double realc(const Complex & x){return realc(x);}
 
 void initArrayOperatorComplex()
 {
     typedef Complex K;
     typedef const K & KK;
+    typedef double R;
+    typedef const R & RR;
     ArrayOperator<Complex,long>();
     ArrayOperatorF<Complex,const Complex&>();
      // take the real or imag part of complex array
@@ -80,8 +86,13 @@ void initArrayOperatorComplex()
     
     Global.Add("square","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(square));
     Global.Add("conj","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(conj));
-
-    map_type[typeid(SetArray<K>).name()]->AddCast(					     
+//    Global.Add("imag","(",new OneOperator1F_KN_<F_KN_<R,R,K,KK>,R,KK,KN_<K> >(imagc));
+//    Add<KN_<double> >("<--","(",new OneOperator1F_KN_<F_KN_<R,R,K,KK>,R,KK,KN_<K> >(realc));
+    TheOperators->Add("*",
+                      new OneBinaryOperator<Op2_2p_<Mul_KNMh_KN_<K>,Transpose<KNM<K>*>,KN<K>*> >);// A'*b zzzzzzz
+    TheOperators->Add("=",new OneBinaryOperator<init_eqarray<KN<K> ,Mul_KNMh_KN_<K> > > );
+    TheOperators->Add("<-",new OneBinaryOperator<init_eqarray<KN<K> ,Mul_KNMh_KN_<K> > > );
+    map_type[typeid(SetArray<K>).name()]->AddCast(
 						  new E_F1_funcT<SetArray<K>,SetArray<long> >(Cast<SetArray<K>,SetArray<long> >),
 						  new E_F1_funcT<SetArray<K>,SetArray<double> >(Cast<SetArray<K>,SetArray<double> >)
 	  					      
