@@ -31,6 +31,8 @@
 #include "config-wrapper.h"
 #include <set>
 #include <complex>
+//#include <type_traits>
+
 #include "AFunction.hpp"
 #include <cstdarg>
 #include <cstring>
@@ -189,7 +191,11 @@ inline   K * get_element( MyMap<String,K> *  const  &  a,string*  const   & b)
   //  cout << "get_element " << *b << " : " << ret << " = "<< * ret << endl;
    // delete b;  modif mars 2006 auto del ptr
     return ret;}
-    
+
+template<class K>
+inline   bool exist_element( MyMap<String,K> *  const  &  a,string*  const   & b)
+{     return  a->exist(*b);}
+
 template<>
 inline   string ** get_element<string*>( MyMap<String,string*> *  const  &  a,string*  const   & b)
  { string** ret=  &((*a)[*b]); // correction FH feb 2004
@@ -303,13 +309,108 @@ RR * get_elementp2__(const A & a,const B & b,const C & c){
 return  &((a)(b,c));}
 
 
-    
+template<typename T>
+struct myremove_pointer
+{
+    typedef T type;
+};
 
-template<class RR,bool isinit>
+template<typename T>
+struct myremove_pointer<T*>
+{
+    typedef typename myremove_pointer<T>::type type;
+};
+
+template<class Map,class Key, class Value,bool isinit>
+class  InitMapfromArray : public OneOperator {
+public:
+   typedef typename  myremove_pointer<Map>::type MMap ;
+  //  typedef typename KNR::K RR;
+    typedef Map  A;
+    typedef Map  R;
+    typedef E_Array B;
+    
+    class CODE : public  E_F0 { public:
+        Expression a0;
+        int N;
+        Expression * tab;
+        int * what;//  0  RR, 1 KN<RR>,
+        const  bool mi;
+        /*
+         static KN_<RR> &set(KN<RR> * a,KN<RR> *& p,int n){
+            if(isinit) a->init(n);
+            else a->resize(n);
+            p =a;
+            return *a;}*/
+        
+       /* static KN_<RR> &set(KN_<RR> & a,KN<RR> *& p,int n){p=0;return a;}*/
+        
+        CODE(Expression a,const E_Array & tt)
+        : a0(a),N(tt.size()),
+        tab(new Expression [N]),
+        what(new int[N])  ,
+        mi(tt.MeshIndependent())
+        
+        {
+            assert(&tt);
+            //      int err=0;
+            for (int i=0;i<N;i++)
+                if(i%2==0 && atype<Key>()->CastingFrom(tt[i].right() ) )
+                {
+                    tab[i]=atype<Key>()->CastTo(tt[i]);
+                    what[i]=1;
+                }
+               else if(i%2==1 && atype<Value>()->CastingFrom(tt[i].right() ) )
+            {
+                tab[i]=atype<Value>()->CastTo(tt[i]);
+                what[i]=1;
+            }
+
+                 else
+                    CompileError(" InitMapfromArray: we are waiting for Key or Value  type");
+        }
+        AnyType operator()(Stack stack)  const
+        {
+          
+            A  aa=GetAny<A>((*a0)(stack));
+            if(isinit) aa->init();
+            for(int i=0,j=0; i<N/2; ++i)
+            {
+                Key k= GetAny<Key>((*(tab[j++]))(stack));
+              //  String sk(*k);
+                Value v= GetAny<Value>((*(tab[j++]))(stack));
+    
+                //cout << "InitMapfromArray  "<< *k << " " << (string) sk << " "<<  v << endl;
+                aa->insert(*k,v);
+            }
+          return SetAny<R>(aa);
+        }
+        bool MeshIndependent() const     {return  mi;} //
+        ~CODE() { delete [] tab; delete[] what;}
+        operator aType () const { return atype<R>();}
+    }; // end sub class CODE
+    
+    
+public:
+    E_F0 * code(const basicAC_F0 & args) const
+    {   if(verbosity>9999)
+        cout << "\n code InitMapfromArray:" << *args[0].left() << " " << *args[1].left()
+        << "( "<< *t[0] << " " << *t[1] <<")" <<endl;
+        return  new CODE(t[0]->CastTo(args[0]),*dynamic_cast<const E_Array*>( t[1]->CastTo(args[1]).LeftValue()));}
+    InitMapfromArray(int preff=0):   OneOperator(atype<R>(),atype<A>(),atype<B>())  {
+        pref=preff;
+    }
+    
+};
+
+
+template<class KNRR,bool isinit>
 class  InitArrayfromArray : public OneOperator { 
 public:
-    typedef KN<RR> * A;
-    typedef KN<RR> * R;
+    typedef typename  myremove_pointer<KNRR>::type KNR ;
+    typedef typename KNR::K RR;
+    typedef KNRR  A;
+    typedef KNRR  R;
     typedef E_Array B;
     
     class CODE : public  E_F0 { public:
@@ -318,7 +419,15 @@ public:
        Expression * tab;
     int * what;//  0  RR, 1 KN<RR>, 
        const  bool mi;
-
+        
+    static KN_<RR> &set(KN<RR> * a,KN<RR> *& p,int n){
+                if(isinit) a->init(n);
+                else a->resize(n);
+        p =a;
+        return *a;}
+        
+    static KN_<RR> &set(KN_<RR> & a,KN<RR> *& p,int n){p=0;return a;}
+        
     CODE(Expression a,const E_Array & tt)  
       : a0(a),N(tt.size()),
 	tab(new Expression [N]),
@@ -342,13 +451,14 @@ public:
 	else 
 	  CompileError(" InitArrayfromArray: we are waiting for scalar or vector of scalar");
     }
-    
-    AnyType operator()(Stack stack)  const 
+    AnyType operator()(Stack stack)  const
     {
+        // a verifier ... FH nov 2015.....
 	//extern void xxxx();
 	//xxxx();
-      A  a=GetAny<A>((*a0)(stack));
-      KN<AnyType> v(N);
+      KN<RR> * pa=0;
+      A  aa=GetAny<A>((*a0)(stack));
+       KN<AnyType> v(N);
       KN<int>  nn(N+1);
       for (int i=0;i<N;i++)
         v[i]= (*(tab[i]))(stack);
@@ -360,19 +470,21 @@ public:
 	  else if (what[i]==1) nn[i]=GetAny<KN_<RR> >(v[i]).size();
           n += nn[i];
 	}
-      if (isinit) 
-        a->init(n);
-      else
-	a->resize(n);
-      
+        if(verbosity>10000)cout << " InitArrayfromArray  aa = " <<aa << " n="<< n << endl;
+        KN_<RR> a =set(aa,pa,n);       
+        if(verbosity>10000) cout << " InitArrayfromArray a.N() "<< a.N() << " " << n << " "
+                             << pa << " " << isinit  <<endl;
+        ffassert(a.N()>=n);
       for (int i=0,j=0 ;i<N; j += nn[i++])
-	
+      {
+       // cout << " ### " << i << " " << j << endl;
         if (what[i]==0)
-          (*a)[j]= GetAny<RR>(v[i]);
+          a[j]= GetAny<RR>(v[i]);
         else if (what[i]==1) 
-          (*a)(SubArray(nn[i],j)) = GetAny<KN_<RR> >((*(tab[i]))(stack));// correct bug nov 2014
+          a(SubArray(nn[i],j)) = GetAny<KN_<RR> >((*(tab[i]))(stack));// correct bug nov 2014
+      }
         //  (due to resize=> pointer  change Fh
-      return SetAny<R>(a);
+      return SetAny<R>(aa);
     } 
     bool MeshIndependent() const     {return  mi;} // 
     ~CODE() { delete [] tab; delete[] what;}
@@ -382,8 +494,14 @@ public:
   
     public: 
     E_F0 * code(const basicAC_F0 & args) const 
-     { return  new CODE(t[0]->CastTo(args[0]),*dynamic_cast<const E_Array*>( t[1]->CastTo(args[1]).LeftValue()));} 
-    InitArrayfromArray():   OneOperator(atype<R>(),atype<A>(),atype<B>())  {}
+    {   if(verbosity>9999)
+          cout << "\n code InitArrayfromArray:" << *args[0].left() << " " << *args[1].left()
+               << "( "<< *t[0] << " " << *t[1] <<")" <<endl;
+         return  new CODE(t[0]->CastTo(args[0]),*dynamic_cast<const E_Array*>( t[1]->CastTo(args[1]).LeftValue()));}
+    InitArrayfromArray(int preff=0):   OneOperator(atype<R>(),atype<A>(),atype<B>())  {
+        pref=preff;
+       // cout << "\n @@@ R " << *atype<R>()<< " A " << *atype<A>() << " B " << * atype<B>() << " " << preff <<endl;
+    }
   
 };
 
@@ -494,7 +612,7 @@ public:
 	    what[i]=1;
 	  }      
 	else 
-	  CompileError(" we are waiting for scalar or vector of scalar");
+	  CompileError("SetArrayofKNfromKN: we are waiting for scalar or vector of scalar");
     }
     
     AnyType operator()(Stack stack)  const 
@@ -649,6 +767,11 @@ template<class A> inline AnyType DestroyKN(Stack,const AnyType &x){
     return  Nothing;
 }
 
+template<typename K>
+AnyType TransposeKNM(Stack,const AnyType &a) {
+    Transpose< KNM<K> * > ta(GetAny<Transpose< KNM<K> * > >(a));
+    return  SetAny<KNM_<K> >((*ta.t).t());}
+
 template<class K>
 void ArrayDCL()
 {
@@ -701,7 +824,8 @@ void ArrayDCL()
        
        ); 
     map_type[typeid(KNM_<K> ).name()]->AddCast(
-					      new E_F1_funcT<KNM_<K>,KNM<K>*>(UnRefpKN<KNM<K>,KNM_<K> >  )
+					      new E_F1_funcT<KNM_<K>,KNM<K>*>(UnRefpKN<KNM<K>,KNM_<K> > ) ,
+                                              new E_F1_funcT<KNM_<K>,Transpose< KNM<K> *> >(TransposeKNM<K>)
 					      ); 
     
     //   ,new E_F1_funcT<KN_<K>,K>(ValueToKN_<K>),
@@ -719,6 +843,12 @@ void ArrayDCL()
     map_type_of_map[make_pair(atype<long>(),atype<KN_<K> >())]=atype<KN<KN<K> >*>();// tableau de tableau
     map_type_of_map[make_pair(atype<long>(),atype<KNM_<K> >())]=atype<KN<KNM<K> >*>();// tableau de matrix 
 
+    // Add FH for loop 2015
+    atype<KN<K>*>()->SetTypeLoop(atype<K*>(),atype<long*>());
+    atype<KNM<K>*>()->SetTypeLoop(atype<K*>(),atype<long*>(),atype<long*>());
+    atype<KN_<K> >()->SetTypeLoop(atype<K*>(),atype<long*>());
+    atype<KNM_<K> >()->SetTypeLoop(atype<K*>(),atype<long*>(),atype<long*>());
+    
 }
 
 
@@ -806,7 +936,7 @@ struct Op3_pacc: public ternary_function<KN_<K>,K,K,if_arth_KN_<K>*> {
 	       kb(new(NewAllocTmp(s,sizeof(b))) K(b),1,0);    
     return new if_arth_KN_<K>(a,kb,kc);}
 };   
-
+template<class K> KNM_<K> Transp(KNM_<K>  M){ return M.t();} // Add FH July 2015
 template<class K>
 struct SetArray2: public binary_function<K,K,SetArray<K> > { 
   static SetArray<K> f(const K & a,const K & b)  { 
@@ -918,6 +1048,121 @@ long Unique(KN<K>* const& array, KN<L>* const& val)
         (*val)[i++] = *it;
     return vals.size();
 }
+
+
+
+
+
+template<class K>
+class E_ForAllLoopRNM
+{  public:
+    typedef KNM_<K> Tab;
+    typedef  ForAllLoopOpBase DataL;
+    const DataL *data;
+    E_ForAllLoopRNM(const DataL *t): data(t){}
+    AnyType f(Stack s) const {
+        Tab t= GetAny<KNM_<K> >(data->tab(s));
+        long * i=   GetAny<long * >(data->i(s));
+        long * j=  GetAny<long * >(data->j(s));
+        K * v   =   GetAny<K * >(data->v(s));
+        if(verbosity>1000) {
+        cout << i << " " << j << " " << v << " " << data->epl <<     endl;
+        cout << " i " << (char*) (void *) i -  (char*)(void*) s ;
+        cout << " j " <<  (char*)(void *) j -  (char*)(void*) s ;
+        cout << " vij " <<  (char*) (void *) v -  (char*)(void*) s ;
+        cout << endl;
+        }
+        
+        ffassert(i && j && v);
+        for ( *i=0;*i<t.N();++*i)
+            for ( *j=0;*j<t.M();++*j)
+            {
+                *v = t(*i,*j);
+                data->code(s);
+                t(*i,*j)= *v;
+            }
+        data->end(s);
+        return Nothing  ;
+     }
+    
+};
+
+template<class K>
+class E_ForAllLoopRN
+{  public:
+    typedef KN_<K> Tab;
+    typedef  ForAllLoopOpBase DataL;
+    const DataL *data;
+    E_ForAllLoopRN(const DataL *t): data(t){}
+    AnyType f(Stack s) const {
+        Tab t= GetAny<KN_<K> >(data->tab(s));
+        long * i=   GetAny<long * >(data->i(s));
+        K * v   =   GetAny<K * >(data->v(s));
+  //      cout << i << " " << j << " " << v << " " << data->epl <<     endl;
+         if(verbosity>1000) {
+        cout << " i " << (char*) (void *) i -  (char*)(void*) s ;
+        cout << " vi " <<  (char*) (void *) v -  (char*)(void*) s ;
+        cout << endl;
+         }
+        
+        ffassert(i && v);
+        for ( *i=0;*i<t.N();++*i)
+            {
+                *v = t[*i];
+                data->code(s);
+                t[*i]= *v;
+            }
+        data->end(s);
+        return Nothing  ;
+    }
+    
+};
+
+template<class V>
+class E_ForAllLoopMapSI
+{  public:
+    typedef String K;
+    typedef string *KK;
+    typedef V *VV;
+    
+    typedef MyMap<K,V>  *Tab;
+    typedef typename  MyMap<K,V>::iterator TabI ;
+    
+    typedef  ForAllLoopOpBase DataL;
+    const DataL *data;
+    E_ForAllLoopMapSI(const DataL *t): data(t){}
+    AnyType f(Stack s) const {
+        Tab t= GetAny<Tab >(data->tab(s));
+        KK * i   =   GetAny<KK*>(data->i(s));
+        VV  v   =   GetAny<VV >(data->v(s));
+        //      cout << i << " " << j << " " << v << " " << data->epl <<     endl;
+        if(verbosity>1000) {
+        cout << " i " << (char*) (void *) i -  (char*)(void*) s ;
+        cout << " vi " <<  (char*) (void *) v -  (char*)(void*) s ;
+        cout << endl;
+        }
+        
+        ffassert(i && v);
+        if(t->m)
+            for (TabI ii=t->m->begin();ii != t->m->end();++ii)
+            {
+                String  kk = ii->first;
+                V  vv = ii->second;
+                
+                *i =  kk;
+                *v =  vv;
+                // for  Windows otherwise trap ???? FH. march 2016
+                if(verbosity>99999) cout << " " << i << " "<< v  << " "  << kk << " " <<  vv << endl;
+                 data->code(s);
+                
+                ii->second  = *v;
+                *i=0;
+            }
+        data->end(s);
+        return Nothing  ;
+    }
+    
+};
 extern aType aaaa_knlp;
 template<class K,class Z>
 void ArrayOperator()
@@ -1033,7 +1278,7 @@ void ArrayOperator()
     
      TheOperators->Add("<-", 
        new OneOperator2_<KN<K> *,KN<K> *,Z>(&set_init),
-       new InitArrayfromArray<K,true>
+       new InitArrayfromArray<KN<K>*,true>
     //   new OneOperator2_<KN<K> *,KN<K> *,KN<K> >(&set_init),
     //   new OneOperator2_<KN<K> *,KN<K> *,KN_<K> >(&set_init)		????       
      //  new OneOperator2_<KN<K> *,KN<K> *,KN<K> * >(&set_initp)
@@ -1064,7 +1309,7 @@ void ArrayOperator()
 
     // Add<KNM<K> *>("=","(",new OneOperator2_<KNM<K> *,KNM<K> *,Transpose<KNM<K> * > >(&set_tt));
     
-     Add<KN<K> *>("<-","(",new InitArrayfromArray<K,true>);
+     Add<KN<K> *>("<-","(",new InitArrayfromArray<KN<K>*,true>);
      Add<KNM<K> *>("<-","(",new InitMatfromAArray<K,true>);
      Add<KN<K> *>("n",".",new OneOperator1<Z,KN<K> *>(get_n));
      Add<KNM<K> *>("n",".",new OneOperator1<Z,KNM<K> *>(get_n));
@@ -1084,9 +1329,9 @@ void ArrayOperator()
     
 //     AddOpeqarray<set_eqarray,KN,K>("=");
 
-     TheOperators->Add("=", new InitArrayfromArray<K,false>
-       );
-     TheOperators->Add("=", new InitMatfromAArray<K,false>
+     TheOperators->Add("=", new InitArrayfromArray<KN<K>*,false>(10));
+     TheOperators->Add("=", new InitArrayfromArray<KN_<K>,false>(1));// ???????? FH nov 2015 ..
+    TheOperators->Add("=", new InitMatfromAArray<K,false>
        );
      TheOperators->Add("=", new SetArrayofKNfromKN<K>
        );
@@ -1289,7 +1534,8 @@ void ArrayOperator()
      //-  new OneBinaryOperator<Op2_mulcp<Mulc_KN_<K>,K,KN<K>*> >,
        new OneBinaryOperator<Op2_mulc<Mulc_KN_<K>,KN_<K>,K> >,
        new OneBinaryOperator<Op2_mulc<Mulc_KN_<K>,K,KN_<K> > >,
-       new OneBinaryOperator<Op2_mulpcp<Mul_KNM_KN_<K>,KNM<K>*,KN<K>*> >,
+       new OneBinaryOperator<Op2_mulpcp<Mul_KNM_KN_<K>,KNM<K>*,KN<K>*> >,// A*b zzzzzzz
+                       
       // new OneBinaryOperator<Op2_mulp<Mul_KNM_KN_<K>,KNM_<K>,KN_<K>> >, // - add #1 mqi 2009 
       // new OneBinaryOperator<Op2_dotproduct<K> >,
        new OneBinaryOperator<Op2_dotproduct_<K> > 
@@ -1350,7 +1596,8 @@ void ArrayOperator()
   TheOperators->Add("\'",       
       // new OneOperator1<Transpose<KN_<K> >,KN<K> *>(&Build<Transpose<KN_<K> >,KN<K> *>),
        new OneOperator1<Transpose<KN_<K> >,KN_<K> >(&Build<Transpose<KN_<K> >,KN_<K> >),
-       new OneOperator1<Transpose<KNM<K> * >, KNM<K> * >(&Build<Transpose<KNM<K> * >,KNM<K> * >)            
+       new OneOperator1<Transpose<KNM<K> * >, KNM<K> * >(&Build<Transpose<KNM<K> * >,KNM<K> * >,10)  ,
+       new OneOperator1<KNM_<K> , KNM_<K> >(Transp<K>, 1)
   );
        
      TheOperators->Add(".*",
@@ -1390,7 +1637,9 @@ void ArrayOperator()
      map_type_of_map[make_pair(atype<string*>(),atype<K>())]=atype<MyMap<String,K>*>(); 
      
      atype<MyMap<String,K>*>()->Add("[","",new OneOperator2_<K*,MyMap<String,K>*,string*>(get_element<K>));
-    
+     TheOperators->Add("&",new OneOperator2_<bool,MyMap<String,K>*,string*>(exist_element<K>));
+    TheOperators->Add("<<",new OneBinaryOperator<PrintP<MyMap<String,K>*> >);
+   
     // Add Mai 2009
     Dcl_Type<SetArray<K> >();
     TheOperators->Add("::",
@@ -1406,6 +1655,16 @@ void ArrayOperator()
 		      new OneOperator2_<KN_<K> ,KN_<K> ,SetArray<K> >(-1,&set_array_) // missing aug 2009 a(:)=1:3 less prioritaire
     );
     
+    atype<MyMap<String,K>*>()->SetTypeLoop(atype<K*>(),atype<string**>());
+
+    
+    TheOperators->Add("{}",new ForAllLoop<E_ForAllLoopMapSI<K> >);
+
+    TheOperators->Add("{}",new ForAllLoop<E_ForAllLoopRNM<K> >);
+    TheOperators->Add("{}",new ForAllLoop<E_ForAllLoopRN<K> >);
+    
+    TheOperators->Add("<-",new InitMapfromArray<MyMap<String,K>*,string *,K,true> );
+
 }
 
 template<class R,class A,class B=A,class BB=B>
