@@ -35,6 +35,7 @@
 
 // set in getprog-unix.hpp in Graphic dir..
 const char *  prognamearg=0;
+extern  void (*initparallele)(int &, char **&); // to know if mpiversion ... 
 
 #ifdef PURE_WIN32
 #include <windows.h>
@@ -55,6 +56,20 @@ const char BACKSLACH='\\';
  const  char dirnsep=BACKSLACH, dirsep=SLACH;
 #endif
 
+#include <sys/stat.h>
+
+int dirExists(const string & path)
+{
+    struct stat info;
+    
+    if(stat( path.c_str(), &info ) != 0)
+        return 0;
+    else if(info.st_mode & S_IFDIR)
+        return 1;
+    else
+        return 0;
+}
+
 string DirName(const char * f)
 {
   const char *c= strrchr(f,dirsep);
@@ -116,6 +131,15 @@ bool EnvironmentInsert(string key,string item,string before)
 {
    bool ret=true;
    OneEnvironmentData  & l = ffenvironment[key];
+   char  sufmpi[] = {'m','p','i',dirsep,'\0'};
+   string suf= ((key== "loadpath") && initparallele ) ? sufmpi  : "";
+    if( verbosity > 1000) cout << " **EnvironmentInsert " <<initparallele<< " suf '"
+        << suf << "'  " << item <<endl;
+   if( ! suf.empty() && dirExists(item+suf) )
+    {
+	 if(verbosity>=100)  cout << " EnvironmentInsert: Add suf " << suf << " to " << item << " in GetEnvironment "<< key << endl; 
+	 item  += suf;
+    }
    
    OneEnvironmentData::iterator i=find(l.begin(),l.end(),item);
    
@@ -132,7 +156,7 @@ bool EnvironmentInsert(string key,string item,string before)
 
 int GetEnvironment(const string & key, string items)
 {
-  if(verbosity>=100)  cout << key << " -> " << items << endl;
+  if(verbosity>=100)  cout << key << " -> " << items <<  endl;
   bool path=key.find("path")!= string::npos;
   int d=0, k=0;
   if(path)
@@ -305,8 +329,12 @@ void GetEnvironment()
   if (GetEnvironmentVariable("HOMEPATH", envh, LEN) > 0) 
     home=envh;
 #endif 
-  if ( ff_verbosity ) { 
+  if ( ff_verbosity ) {
+    
     verbosity = atoi(ff_verbosity);
+      if(verbosity > 4)
+    cout << " -- GetEnvironmentVariable: verbosity= " <<verbosity   << endl;
+      
   }
 
 #ifdef PURE_WIN32 
@@ -345,9 +373,9 @@ void GetEnvironment()
   
   
   
-  if ( ff_verbosity ) { 
-    verbosity = atoi(ff_verbosity);
-  }
+ // if ( ff_verbosity ) {
+ //   verbosity = atoi(ff_verbosity);
+ // }
   if(ff_loadpath)
     GetEnvironment("loadpath",ff_loadpath);
   if(ff_incpath)
@@ -366,10 +394,10 @@ void GetEnvironment()
 	show("\ninclude path : ",inc->second, "\n \t ");
 	cout <<"(.)"<<endl;}
     }
-  if ( ff_verbosity ) { 
-    verbosity = atoi(ff_verbosity);
-    if(verbosity>2) cout << " --  verbosity is set to " << verbosity << endl;
-  }
+//  if ( ff_verbosity ) {
+//    verbosity = atoi(ff_verbosity);
+    if(verbosity>10) cout << " --  GetEnvironment: verbosity is set to " << verbosity  << endl;
+//  }
   
  }
 void EnvironmentLoad()
@@ -385,7 +413,42 @@ void EnvironmentLoad()
 	    
 }
 
- 
+//  from ffapi to env. F. Hecht ..
+#include "ffapi.hpp"
+#include <dirent.h>
+#include <strings.h>
+#ifdef _WIN32
+#include <windows.h>
+#else
+#include <unistd.h>
+#endif
+
+namespace ffapi
+{
+// to change to tmp dir for exec ...
+long chtmpdir()
+{
+    char tmp[256];
+#ifdef _WIN32
+    strcpy(tmp,"c:\\Temp");
+    if (GetEnvironmentVariable("TEMP", tmp, 256) > 0);
+#else
+    strcpy(tmp,"/tmp/");
+#endif
+    if(verbosity>2)
+        std::cout << " Change to " << endl;
+    return chdir(tmp);
+    
+}
+bool ff_justcompile=false;
+bool ff_ch2edpdtmpir=0;
+void ifchtmpdir()
+{
+    if(ff_ch2edpdtmpir) {
+    }
+}
+}
+
 #ifdef TESTMAIN
 long verbosity=50;
  EnvironmentData  environment;
@@ -394,5 +457,5 @@ int main()
   GetEnvironment();
   return 0; 
 }
-
+}
 #endif
