@@ -32,6 +32,7 @@
 #include <iostream>
 #include <sstream>
 #include <cstdio>
+#include <cstring>
 using namespace std;
 #endif //FFAPI_HPP
 
@@ -44,9 +45,9 @@ typedef void (*AtEnd)();
 void ff_atend(AtEnd f);
 // big change F. Hecht Frev 2015
 // passe all function by pointer
-
 namespace ffapi{
-
+   extern  bool ff_ch2edpdtmpir;
+   extern bool ff_justcompile;
   // Redirecting the FF data stream
   // ------------------------------
 
@@ -109,6 +110,8 @@ namespace ffapi{
   /// commands) are not allowed.
 
   extern bool (*protectedservermode)();
+  extern  void ifchtmpdir();
+  extern  long chtmpdir();
 }
 
 #endif // FFAPI_HPP
