@@ -114,8 +114,10 @@ namespace ffapi {
 
 /// <<verbosity>>
 long verbosity = 1;
-
  long searchMethod = 0; //pichon
+long npichon2d=0, npichon3d=0;
+long npichon2d1=0, npichon3d1=0;
+
  FILE *ThePlotStream=0; //  Add for new plot. FH oct 2008
 
   KN<String> *pkarg;//  for the list of argument  mars 2010 
@@ -140,7 +142,7 @@ YYSTYPE *plglval;
 // const C_F0 & One(*pOne), &Zero(*pZero);
  
  Polymorphic * TheOperators=0, //=new Polymorphic(), 
-             * TheRightOperators=0; //=new Polymorphic();
+             * TheRightOperators=0;//=new Polymorphic();
 
 /// <<Global>> Contains all FreeFem++ language keywords. Declaration in [[file:AFunction.hpp::Global]]
 
@@ -173,6 +175,9 @@ EnvironmentData  ffenvironment;
 
 basicForEachType *basicForEachType::tnull=0;
 E_F0 *E_F0::tnull=0;
+
+long newconvect3=0;// old convect 3d
+
 CodeAlloc *CodeAlloc::tnull=0;
 
 #include <RefCounter.hpp>
