@@ -34,8 +34,8 @@ using Fem2D::MeshPoint;
 
 extern bool NoWait; 
 
-typedef Mesh * pmesh;
-typedef Mesh3 * pmesh3;
+typedef Mesh const * pmesh;
+typedef Mesh3 const * pmesh3;
 
 map<pair<int,int>,int>::iterator closeto(map<pair<int,int>,int> & m, pair<int,int> & k)
 {
@@ -390,12 +390,12 @@ public:
   typedef double R;
   typedef typename Mesh::Rd Rd;
   typedef typename Mesh::Vertex Vertex;
-  CountPointer<Mesh> pTh;
+  CountPointer<const Mesh> pTh;
   const Vertex *v;
   void Check() const {   if (!v || !pTh) { ExecError("Too bad! Unset Vertex!"); } }
   void init() { v=0;pTh.init();}
-  GlgVertex(Mesh * Th,long kk): pTh(Th),v( &(*pTh)(kk)) {}
-  GlgVertex(Mesh * Th,const Vertex * kk): pTh(Th),v(kk) {}
+  GlgVertex(const Mesh * Th,long kk): pTh(Th),v( &(*pTh)(kk)) {}
+  GlgVertex(const Mesh * Th,const Vertex * kk): pTh(Th),v(kk) {}
   operator int() const { Check(); return (* pTh)(v);} 
   operator Rd*(){ Check(); return v;} 
   R x() const {Check() ; return v->X();}
@@ -410,7 +410,7 @@ class GlgElement { public:
 typedef typename Mesh::Element Element;
 
     struct Adj {// 
-	Mesh *pTh;
+	const Mesh *pTh;
 	const Element *k;
 	Adj(const GlgElement<Mesh> & pp) : pTh(pp.pTh),k(pp.k) {}
 	GlgElement<Mesh> adj(long & e) const  {
@@ -423,15 +423,15 @@ typedef typename Mesh::Element Element;
 	return  GlgElement<Mesh>(pTh,kk);}
     }; 
     
-    CountPointer<Mesh> pTh;
+    CountPointer<const Mesh> pTh;
   const Element *k;
   
   GlgElement():  k(0) {}
   void  Check() const  {   if (!k || !pTh) { ExecError("Unset Triangle,Sorry!"); } }
   void init() { k=0;pTh.init();}
   void destroy() {pTh.destroy();}
-  GlgElement(Mesh * Th,long kk): pTh(Th),k( &(*pTh)[kk]) {}
-  GlgElement(Mesh * Th,Element * kk): pTh(Th),k(kk) {}
+  GlgElement(const Mesh * Th,long kk): pTh(Th),k( &(*pTh)[kk]) {}
+  GlgElement(const Mesh * Th,Element * kk): pTh(Th),k(kk) {}
   operator int() const { Check(); return (* pTh)(k);} 
   GlgVertex<Mesh> operator [](const long & i) const { Check(); return GlgVertex<Mesh>(pTh,&(*k)[i]);}   
   long lab() const {Check() ; return k ? k->lab : 0;}
@@ -452,21 +452,21 @@ class GlgBoundaryElement { public:
     typedef typename Mesh::BorderElement BorderElement;
     
     struct BE {
-	Mesh * p;
-	BE(Mesh *pp) : p(pp) {}
-	BE(Mesh **pp) : p(*pp) {}
-	operator Mesh * () const {return p;}
+	const Mesh * p;
+	BE(const Mesh *pp) : p(pp) {}
+	BE(const Mesh **pp) : p(*pp) {}
+	operator const Mesh * () const {return p;}
     };
     
-    CountPointer<Mesh> pTh;
-    BorderElement *k;
+    CountPointer<const Mesh> pTh;
+    const BorderElement *k;
     
     GlgBoundaryElement():  k(0) {}
     void  Check() const  {   if (!k || !pTh) { ExecError("Unset BoundaryEdge,Sorry!"); } }
     void init() { k=0;pTh.init();}
     void destroy() {pTh.destroy();}
-    GlgBoundaryElement(Mesh * Th,long kk): pTh(Th),k( &(*pTh).be(kk)) {}
-    GlgBoundaryElement(Mesh * Th,BoundaryEdge * kk): pTh(Th),k(kk) {}
+    GlgBoundaryElement(const Mesh * Th,long kk): pTh(Th),k( &(*pTh).be(kk)) {}
+    GlgBoundaryElement(const Mesh * Th,BoundaryEdge * kk): pTh(Th),k(kk) {}
     GlgBoundaryElement(const BE & be,long kk): pTh(be.p),k( &(*pTh).be(kk)) {}
     GlgBoundaryElement(const BE & be,BoundaryEdge * kk): pTh(be.p),k(kk) {}
     operator int() const { Check(); return (* pTh)(k);} 
@@ -510,6 +510,25 @@ double pmesh_mesb(pmesh3 * p) { ffassert(p && *p) ;  return (**p).mesb;}
 long pmesh_nt(pmesh3 * p) { ffassert(p && *p) ;  return (**p).nt ;}
 long pmesh_nv(pmesh3 * p) { ffassert(p && *p) ;  return (**p).nv ;}
 long pmesh_nbe(pmesh3 * p) { ffassert(p && *p) ;  return (**p).nbe ;}
+double pmesh_hmax(pmesh3 * p)
+{ ffassert(p && *p) ;
+    double hmax2 =0;
+    const Mesh3 & Th = **p;
+    for(int k=0; k< Th.nt; ++k)
+        for(int e=0; e<6; ++e)
+            hmax2=max(hmax2,Th[k].Edge(e).norme2());
+    return sqrt(hmax2);}
+
+double pmesh_hmin(pmesh3 * p)
+{ throwassert(p && *p) ;
+    double hmin2 =1e100;
+    const Mesh3 & Th = **p;
+    for(int k=0; k< Th.nt; ++k)
+        for(int e=0; e<6; ++e)
+            hmin2=min(hmin2,Th[k].Edge(e).norme2());
+    return sqrt(hmin2);}
+
+
 
 pf3rbase* get_element(pf3rbasearray *const & a, long const & n)
 {
@@ -591,7 +610,8 @@ AnyType ReadMesh3::operator()(Stack stack) const
   using  Fem2D::MeshPointStack;
  
   string * fn =  GetAny<string*>((*filename)(stack));
-  cout << "ReadMesh3 " << *fn << endl;
+  if(verbosity > 2)
+      cout << "ReadMesh3 " << *fn << endl;
   Mesh3 *Thh = new Mesh3(*fn);
   Thh->BuildGTree();
   Add2StackOfPtr2FreeRC(stack,Thh);
@@ -1184,6 +1204,13 @@ long pf3r_nbdf(pair<FEbase<K,v_fes3> *,int> p)
    throwassert( !!p.first->Vh);
    return p.first->Vh->NbOfDF;
  }
+template<class K>
+pmesh3 pf3r_Th(pair<FEbase<K,v_fes3> *,int> p)
+{
+    if (!p.first->Vh) p.first->Vh= p.first->newVh();
+    throwassert( !!p.first->Vh);
+    return & p.first->Vh->Th;
+}
 
 long pVh3_ndof(pfes3 * p)
  { throwassert(p && *p);
@@ -1194,6 +1221,9 @@ long pVh3_nt(pfes3 * p)
 long pVh3_ndofK(pfes3 * p)
  { throwassert(p && *p);
    FESpace3 *fes=**p;   return (*fes)[0].NbDoF() ;}
+pmesh3 pVh3_Th(pfes3 * p)
+{ throwassert(p && *p);
+    FESpace3 *fes=**p; ;  return &fes->Th ;}
 
 template<class R,int dd,class v_fes>
 AnyType pf3r2R(Stack s,const AnyType &a)
@@ -1510,12 +1540,17 @@ void init_lgmesh3() {
    Add<GlgElement<Mesh3> >("label",".",new OneOperator1_<long,GlgElement<Mesh3> >(getlab));
    Add<GlgElement<Mesh3> >("region",".",new OneOperator1_<long,GlgElement<Mesh3> >(getlab));
    Add<GlgElement<Mesh3> >("mesure",".",new OneOperator1_<double,GlgElement<Mesh3> >(getmes));
+    Add<GlgElement<Mesh3> >("measure",".",new OneOperator1_<double,GlgElement<Mesh3> >(getmes));
    Add<pmesh3*>("mesure",".",new OneOperator1<double,pmesh3*>(pmesh_mes));
+    Add<pmesh3*>("measure",".",new OneOperator1<double,pmesh3*>(pmesh_mes));
    Add<pmesh3*>("bordermesure",".",new OneOperator1<double,pmesh3*>(pmesh_mesb));
    Add<pmesh3*>("nt",".",new OneOperator1<long,pmesh3*>(pmesh_nt));
    Add<pmesh3*>("nv",".",new OneOperator1<long,pmesh3*>(pmesh_nv));
    Add<pmesh3*>("nbe",".",new OneOperator1<long,pmesh3*>(pmesh_nbe));
+    Add<pmesh3*>("hmax",".",new OneOperator1<double,pmesh3*>(pmesh_hmax));
+    Add<pmesh3*>("hmin",".",new OneOperator1<double,pmesh3*>(pmesh_hmin));
 
+    
  TheOperators->Add("<-",
        new OneOperator2_<pf3rbase*,pf3rbase*,pfes3* >(MakePtrFE3_2),
        new OneOperator3_<pf3rbasearray*,pf3rbasearray*,pfes3*,long >(MakePtrFE3_3),  
@@ -1610,10 +1645,15 @@ void init_lgmesh3() {
  /*decommente par J. Morice 14/01/09*/ 
  Add<pf3r>("n",".",new OneOperator1<long,pf3r>(pf3r_nbdf<R>));
  Add<pf3c>("n",".",new OneOperator1<long,pf3c>(pf3r_nbdf<Complex>));
+    
+    Add<pf3r>("Th",".",new OneOperator1<pmesh3 ,pf3r>(pf3r_Th<R>));
+    Add<pf3c>("Th",".",new OneOperator1<pmesh3,pf3c>(pf3r_Th<Complex>));
+    
  Add<pfes3*>("ndof",".",new OneOperator1<long,pfes3*>(pVh3_ndof));
  Add<pfes3*>("nt",".",new OneOperator1<long,pfes3*>(pVh3_nt));
  Add<pfes3*>("ndofK",".",new OneOperator1<long,pfes3*>(pVh3_ndofK));
-
+    Add<pfes3*>("Th",".",new OneOperator1<pmesh3,pfes3*>(pVh3_Th));
+    
  //Add<pf3rbasearray*>("[","",new OneOperator2_<pf3rbase*,pf3rbasearray*,long>(get_element));
  //Add<pf3rarray>("[","",new OneOperator2_<pf3r,pf3rarray,long>(get_element));
  //Add<pf3carray>("[","",new OneOperator2_<pf3c,pf3carray,long>(get_element));
