@@ -18,6 +18,6 @@ string StrVersionNumber(){
 //  buffer.precision(8);
 //  buffer<<VersionNumber();
   static char buffer[100];
-  sprintf(buffer," %9f (date Lun 29 jui 2015 15:34:41 CEST)",VersionNumber());
-  return buffer; //.str()+" (date Lun 29 jui 2015 15:34:41 CEST)" ;
+  sprintf(buffer," %9f (date Ven  3 jui 2016 12:57:03 CEST)",VersionNumber());
+  return buffer; //.str()+" (date Ven  3 jui 2016 12:57:03 CEST)" ;
 }
