@@ -124,6 +124,9 @@ template<> struct MPI_TAG<KN<double>* >   {static const int TAG=12;};
 template<> struct MPI_TAG<KN<Complex>* >   {static const int TAG=13;};
 template<> struct MPI_TAG<Mesh *>   {static const int TAG=1000;};
 template<> struct MPI_TAG<Mesh3 *>   {static const int TAG=1010;};
+template<> struct MPI_TAG<const Mesh *>   {static const int TAG=1000;};
+template<> struct MPI_TAG<const Mesh3 *>   {static const int TAG=1010;};
+
 template<> struct MPI_TAG<Matrice_Creuse<double> *>   {static const int TAG=1020;};
 template<> struct MPI_TAG<Matrice_Creuse<Complex> *>   {static const int TAG=1030;};
 
@@ -320,7 +323,7 @@ struct MPIrank {
   }
   
   
-  const MPIrank & Bcast(Fem2D::Mesh *&  a) const {
+  const MPIrank & Bcast(Fem2D::Mesh const *&  a) const {
     if(verbosity>1) 
       cout << " MPI Bcast  (mesh *) " << a << endl;
     Serialize  *buf=0;
@@ -342,18 +345,19 @@ struct MPIrank {
     if(who != mpirank)
       {
 	if (a) (*a).decrement();
-	a= new Fem2D::Mesh(*buf);
+        Fem2D::Mesh *pTh= new Fem2D::Mesh(*buf);
 	Fem2D::R2 Pn,Px;
-	a->BoundingBox(Pn,Px);
-	a->quadtree=new Fem2D::FQuadTree(a,Pn,Px,a->nv);
+	pTh->BoundingBox(Pn,Px);
+	pTh->quadtree=new Fem2D::FQuadTree(pTh,Pn,Px,pTh->nv);
+        a=pTh;
       }   
     delete buf;      
     return *this;
    }
   
-  const MPIrank & Bcast(Fem2D::Mesh3 *&  a) const {
+  const MPIrank & Bcast(Fem2D::Mesh3 const *&  a) const {
     if(verbosity>1) 
-      cout << " MPI Bcast  (mesh3 *) " << a << endl;
+      cout << " MPI Bcast  (const mesh3 *) " << a << endl;
     Serialize  *buf=0;
     long  nbsize=0;
     if(  who == mpirank)  
@@ -373,8 +377,9 @@ struct MPIrank {
 	if(who != mpirank)
 	  {
 	    if (a) (*a).decrement();
-	    a= new Fem2D::Mesh3(*buf);
-	    a->BuildGTree();
+	    Fem2D::Mesh3 * aa= new Fem2D::Mesh3(*buf);
+	    aa->BuildGTree();
+            a=aa;
 	  }   
 	delete buf;      
 	return *this;
@@ -424,10 +429,10 @@ struct MPIrank {
   // version asyncrone or syncrone  Now 2010 ...
   template<class R>   long Send(Matrice_Creuse<R> * const &  a) const ;
   template<class R>   long Recv(Matrice_Creuse<R>  &  a) const ;
-  long Send(Fem2D::Mesh *  a) const ;
-  long Send (Fem2D::Mesh3 *  a) const ;
-  long Recv(Fem2D::Mesh *& a)  const;  
-  long Recv(Fem2D::Mesh3 *& a) const; 
+  long Send(Fem2D::Mesh const *  a) const ;
+  long Send (Fem2D::Mesh3 const *  a) const ;
+  long Recv(Fem2D::Mesh const *& a)  const;
+  long Recv(Fem2D::Mesh3 const *& a) const; 
 
   operator int () const { return who;}     
 };
@@ -493,7 +498,7 @@ void DoOnWaitMPIRequest(MPI_Request *rq)
 
 }
 
-void DeSerialize(Serialize * sTh,Fem2D::Mesh ** ppTh)
+void DeSerialize(Serialize * sTh,Fem2D::Mesh const ** ppTh)
 {
       if ( *ppTh ) (**ppTh).decrement();
    // cout << " ####"<< sTh << endl;
@@ -506,7 +511,7 @@ void DeSerialize(Serialize * sTh,Fem2D::Mesh ** ppTh)
       pTh->quadtree=new Fem2D::FQuadTree(pTh,Pn,Px,pTh->nv);
 }
 
-void DeSerialize(Serialize * sTh,Fem2D::Mesh3 ** ppTh)
+void DeSerialize(Serialize * sTh,const Fem2D::Mesh3 ** ppTh)
 {
       if ( *ppTh )  (**ppTh).decrement();
       Fem2D::Mesh3 * pTh= new Fem2D::Mesh3(*sTh);
@@ -630,9 +635,9 @@ template<class Mesh>
 class RevcWMeshd : public DoOnWaitMPI_Request,Serialize  
 {
 public:  
-  Mesh ** ppTh;
+  Mesh const ** ppTh;
   int state;
-  RevcWMeshd(const MPIrank *mpirank,Mesh ** ppThh)
+  RevcWMeshd(const MPIrank *mpirank,Mesh const ** ppThh)
     : DoOnWaitMPI_Request(*mpirank),Serialize(sizempibuf,Fem2D::Mesh::magicmesh),
       ppTh(ppThh),state(0)
   {
@@ -679,9 +684,9 @@ template<class Mesh>
 class SendWMeshd : public DoOnWaitMPI_Request,Serialize  
 {
 public:  
-  Mesh ** ppTh;
+  const Mesh ** ppTh;
   int state;
-  SendWMeshd(const MPIrank *mpirank,Mesh ** ppThh)
+  SendWMeshd(const MPIrank *mpirank,const Mesh ** ppThh)
     : DoOnWaitMPI_Request(*mpirank),Serialize((**ppThh).serialize()),
       ppTh(ppThh),state(0)
   {
@@ -786,7 +791,7 @@ template<class R>
   }
 
 
-long MPIrank::Send(Fem2D::Mesh *  a) const {
+long MPIrank::Send(const Fem2D::Mesh *  a) const {
     if(verbosity>100) 
       cout << " MPI << (mesh *) " << a << endl;
     ffassert(a);
@@ -795,7 +800,7 @@ long MPIrank::Send(Fem2D::Mesh *  a) const {
     if( rwm->DoSR() ) delete rwm;
     return MPI_SUCCESS;
   }
-long MPIrank::Send (Fem2D::Mesh3 *  a) const {
+long MPIrank::Send (const Fem2D::Mesh3 *  a) const {
     if(verbosity>100) 
       cout << " MPI << (mesh3 *) " << a << endl;
     ffassert(a);
@@ -824,7 +829,7 @@ long MPIrank::Send (Fem2D::Mesh3 *  a) const {
 */
 
 // new version asyncrone ...  Now 2010 ... 
-long MPIrank::Recv(Fem2D::Mesh *& a) const  {
+long MPIrank::Recv(const Fem2D::Mesh *& a) const  {
     if(verbosity>100) 
 	cout << " MPI >> (mesh *) &" << a << " " << &a << endl;
     RevcWMeshd<Mesh> *rwm= new RevcWMeshd<Mesh>(this,&a);
@@ -834,7 +839,7 @@ long MPIrank::Recv(Fem2D::Mesh *& a) const  {
     return MPI_SUCCESS;
 }
 
-long MPIrank::Recv(Fem2D::Mesh3 *& a) const  {
+long MPIrank::Recv(const Fem2D::Mesh3 *& a) const  {
     if(verbosity>100) 
       cout << " MPI >> (mesh3 *) &" << a << " " << &a << endl;
     RevcWMeshd<Mesh3> *rwm= new RevcWMeshd<Mesh3>(this,&a);
@@ -2286,7 +2291,7 @@ void f_end_parallele()
     /// FFCS: MPI_Finalize() needs to be called later than this (in
     /// ffcs/src/server.cpp)
     ffapi::mpi_finalize();
-    if(mpirank==0 || verbosity>2) cout << "FreeFem++-mpi finalize correctly .\n" << flush ;
+    if(verbosity> 2 || (verbosity>1&&mpirank ==0)) cout << "FreeFem++-mpi finalize correctly .\n" << flush ;
     else if(verbosity>5)  cout << '.' << endl ;
 }
 void f_initparallele(int &argc, char **& argv)
@@ -2300,7 +2305,7 @@ void f_initparallele(int &argc, char **& argv)
   
   mpirank = mpirank1;//MPI::COMM_WORLD.Get_rank();
   mpisize =mpisize1;// MPI::COMM_WORLD.Get_size();
-  if(verbosity> 2 || (mpirank ==0))
+  if(verbosity> 2 || (verbosity>1&&mpirank ==0))
   cout << "initparallele rank " <<  mpirank << " on " << mpisize << endl;
   ff_atend(f_end_parallele); // set end MPI // 
 }
@@ -2308,6 +2313,91 @@ void f_initparallele(int &argc, char **& argv)
 double ffMPI_Wtime() {return MPI_Wtime();}
 double ffMPI_Wtick() {return MPI_Wtick();}
 
+class splitComm_Op : public E_F0mps {
+public:
+    Expression comm;
+    Expression p;
+    Expression splitComm;
+    static const int n_name_param = 2;
+    static basicAC_F0::name_and_type name_param[];
+    Expression nargs[n_name_param];
+    splitComm_Op(const basicAC_F0& args, Expression param1, Expression param2, Expression param3) : comm(param1), p(param2), splitComm(param3) {
+        args.SetNameParam(n_name_param, name_param, nargs);
+    }
+    AnyType operator()(Stack stack) const;
+};
+
+basicAC_F0::name_and_type splitComm_Op::name_param[] = {
+    {"topology", &typeid(long)},
+    {"exclude", &typeid(bool)}
+};
+
+class splitComm : public OneOperator {
+public:
+    splitComm() : OneOperator(atype<long>(), atype<pcommworld>(), atype<long*>(), atype<pcommworld>()) {}
+    E_F0* code(const basicAC_F0& args) const
+    {
+        return new splitComm_Op(args, t[0]->CastTo(args[0]), t[1]->CastTo(args[1]), t[2]->CastTo(args[2]));
+    }
+};
+
+static inline bool splitCommunicator(const MPI_Comm& in, MPI_Comm& out, const bool& exclude, unsigned short& p, const unsigned short& T) {
+    int size, rank;
+    MPI_Comm_size(in, &size);
+    MPI_Comm_rank(in, &rank);
+    if(p > size / 2 && size > 1) {
+        p = size / 2;
+        if(rank == 0)
+            std::cout << "WARNING -- the number of master processes was set to a value greater than MPI_Comm_size, the value has been reset to " << p << std::endl;
+    }
+    p = std::max(p, static_cast<unsigned short>(1));
+    if(exclude) {
+        MPI_Group oldGroup, newGroup;
+        MPI_Comm_group(in, &oldGroup);
+        int* pm = new int[p];
+        if(T == 1)
+            for(int i=0;i<p; ++i) pm[i]=i;
+       //     std::iota(pm, pm + p, 0);
+        else if(T == 2) {
+            float area = size * size / (2.0 * p);
+            *pm = 0;
+            for(unsigned short i = 1; i < p; ++i)
+                pm[i] = static_cast<int>(size - std::sqrt(std::max(size * size - 2 * size * pm[i - 1] - 2 * area + pm[i - 1] * pm[i - 1], 1.0f)) + 0.5);
+        }
+        else
+            for(unsigned short i = 0; i < p; ++i)
+                pm[i] = i * (size / p);
+        bool excluded = std::binary_search(pm, pm + p, rank);
+        if(excluded)
+            MPI_Group_incl(oldGroup, p, pm, &newGroup);
+        else
+            MPI_Group_excl(oldGroup, p, pm, &newGroup);
+        MPI_Comm_create(in, newGroup, &out);
+        MPI_Group_free(&oldGroup);
+        MPI_Group_free(&newGroup);
+        delete [] pm;
+        return excluded;
+    }
+    else {
+        MPI_Comm_dup(in, &out);
+        return false;
+    }
+}
+
+
+AnyType splitComm_Op::operator()(Stack stack) const {
+    bool exclude = nargs[1] ? GetAny<bool>((*nargs[1])(stack)) : false;
+    MPI_Comm* orig_comm = (MPI_Comm*)GetAny<pcommworld>((*comm)(stack));
+    MPI_Comm* new_comm = (MPI_Comm*)GetAny<pcommworld>((*splitComm)(stack));
+    long* pp = GetAny<long*>((*p)(stack));
+    unsigned short p = *pp;
+    long topology = nargs[0] ? GetAny<long>((*nargs[0])(stack)) : 0;
+    bool excluded = splitCommunicator(*orig_comm, *new_comm, exclude, p, topology);
+    *pp = p;
+    return static_cast<long>(excluded);
+}
+
+
 void f_init_lgparallele()
   {
     if(verbosity && mpirank == 0) cout << "parallelempi ";
@@ -2387,8 +2477,8 @@ void f_init_lgparallele()
 		      new OneBinaryOperator<Op_Readmpi<KN<double> > > ,
 		      new OneBinaryOperator<Op_Readmpi<KN<long> > > ,
 		       new OneBinaryOperator<Op_Readmpi<KN<Complex> > > ,
-		      new OneBinaryOperator<Op_Readmpi<Mesh *> > ,
-		      new OneBinaryOperator<Op_Readmpi<Mesh3 *> > ,
+		      new OneBinaryOperator<Op_Readmpi<const Mesh *> > ,
+		      new OneBinaryOperator<Op_Readmpi<const Mesh3 *> > ,
 		      new OneBinaryOperator<Op_Readmpi<Matrice_Creuse<R> > > ,
 		      new OneBinaryOperator<Op_Readmpi<Matrice_Creuse<Complex> > > 
 		      );
@@ -2400,8 +2490,8 @@ void f_init_lgparallele()
 		       new OneBinaryOperator<Op_Writempi<KN<double> * > > ,
 		       new OneBinaryOperator<Op_Writempi<KN<long> * > > ,
 		       new OneBinaryOperator<Op_Writempi<KN<Complex> * > > ,
-		       new OneBinaryOperator<Op_Writempi<Mesh *> > ,
-		       new OneBinaryOperator<Op_Writempi<Mesh3 *> > ,
+		       new OneBinaryOperator<Op_Writempi<const Mesh *> > ,
+		       new OneBinaryOperator<Op_Writempi<const Mesh3 *> > ,
 		       new OneBinaryOperator<Op_Writempi<Matrice_Creuse<R> * > > ,
 		       new OneBinaryOperator<Op_Writempi<Matrice_Creuse<Complex>* > > 
 		       
@@ -2413,8 +2503,8 @@ void f_init_lgparallele()
      Global.Add("Send","(", new OneBinaryOperator<Op_Sendmpi<KN<double> *> >);
      Global.Add("Send","(", new OneBinaryOperator<Op_Sendmpi<KN<long> *> >);
      Global.Add("Send","(", new OneBinaryOperator<Op_Sendmpi<KN<Complex> *> >);
-     Global.Add("Send","(", new OneBinaryOperator<Op_Sendmpi<Mesh *> >);
-     Global.Add("Send","(", new OneBinaryOperator<Op_Sendmpi<Mesh3 *> >);
+     Global.Add("Send","(", new OneBinaryOperator<Op_Sendmpi<const Mesh *> >);
+     Global.Add("Send","(", new OneBinaryOperator<Op_Sendmpi<const Mesh3 *> >);
      Global.Add("Send","(", new OneBinaryOperator<Op_Sendmpi<Matrice_Creuse<R> *> >);
      Global.Add("Send","(", new OneBinaryOperator<Op_Sendmpi<Matrice_Creuse<Complex> *> >);
      
@@ -2424,8 +2514,8 @@ void f_init_lgparallele()
      Global.Add("Isend","(", new OneBinaryOperator<Op_ISendmpi<KN<double> *> >);
      Global.Add("Isend","(", new OneBinaryOperator<Op_ISendmpi<KN<long> *> >);
      Global.Add("Isend","(", new OneBinaryOperator<Op_ISendmpi<KN<Complex> *> >);
-     Global.Add("Isend","(", new OneBinaryOperator<Op_ISendmpi<Mesh *> >);
-     Global.Add("Isend","(", new OneBinaryOperator<Op_ISendmpi<Mesh3 *> >);
+     Global.Add("Isend","(", new OneBinaryOperator<Op_ISendmpi<const Mesh *> >);
+     Global.Add("Isend","(", new OneBinaryOperator<Op_ISendmpi<const Mesh3 *> >);
      Global.Add("Isend","(", new OneBinaryOperator<Op_ISendmpi<Matrice_Creuse<R> *> >);
      Global.Add("Isend","(", new OneBinaryOperator<Op_ISendmpi<Matrice_Creuse<Complex> *> >);
      
@@ -2435,8 +2525,8 @@ void f_init_lgparallele()
       Global.Add("Recv","(", new OneBinaryOperator<Op_Recvmpi<KN<double> > >);
       Global.Add("Recv","(", new OneBinaryOperator<Op_Recvmpi<KN<long> > >);
       Global.Add("Recv","(", new OneBinaryOperator<Op_Recvmpi<KN<Complex> > >);
-      Global.Add("Recv","(", new OneBinaryOperator<Op_Recvmpi<Mesh *> >);
-      Global.Add("Recv","(", new OneBinaryOperator<Op_Recvmpi<Mesh3 *> >);
+      Global.Add("Recv","(", new OneBinaryOperator<Op_Recvmpi<const Mesh *> >);
+      Global.Add("Recv","(", new OneBinaryOperator<Op_Recvmpi<const Mesh3 *> >);
       Global.Add("Recv","(", new OneBinaryOperator<Op_Recvmpi<Matrice_Creuse<R> > >);
       Global.Add("Recv","(", new OneBinaryOperator<Op_Recvmpi<Matrice_Creuse<Complex> > >);
       
@@ -2446,8 +2536,8 @@ void f_init_lgparallele()
       Global.Add("Irecv","(", new OneBinaryOperator<Op_IRecvmpi<KN<double> > >);
       Global.Add("Irecv","(", new OneBinaryOperator<Op_IRecvmpi<KN<long> > >);
       Global.Add("Irecv","(", new OneBinaryOperator<Op_IRecvmpi<KN<Complex> > >);
-      Global.Add("Irecv","(", new OneBinaryOperator<Op_IRecvmpi<Mesh *> >);
-      Global.Add("Irecv","(", new OneBinaryOperator<Op_IRecvmpi<Mesh3 *> >);
+      Global.Add("Irecv","(", new OneBinaryOperator<Op_IRecvmpi<const Mesh *> >);
+      Global.Add("Irecv","(", new OneBinaryOperator<Op_IRecvmpi<const Mesh3 *> >);
       Global.Add("Irecv","(", new OneBinaryOperator<Op_IRecvmpi<Matrice_Creuse<R> > >);
       Global.Add("Irecv","(", new OneBinaryOperator<Op_IRecvmpi<Matrice_Creuse<Complex> > >);
       
@@ -2460,8 +2550,8 @@ void f_init_lgparallele()
       Global.Add("broadcast","(",new OneBinaryOperator<Op_Bcastmpi<KN<double> > >);
       Global.Add("broadcast","(",new OneBinaryOperator<Op_Bcastmpi<KN<long> > >);
       Global.Add("broadcast","(",new OneBinaryOperator<Op_Bcastmpi<KN<Complex> > >);
-      Global.Add("broadcast","(",new OneBinaryOperator<Op_Bcastmpi<Mesh *> >);
-      Global.Add("broadcast","(",new OneBinaryOperator<Op_Bcastmpi<Mesh3 *> >);
+      Global.Add("broadcast","(",new OneBinaryOperator<Op_Bcastmpi<const Mesh *> >);
+      Global.Add("broadcast","(",new OneBinaryOperator<Op_Bcastmpi<const Mesh3 *> >);
       Global.Add("broadcast","(",new OneBinaryOperator<Op_Bcastmpi<Matrice_Creuse<R> > >);
       Global.Add("broadcast","(",new OneBinaryOperator<Op_Bcastmpi<Matrice_Creuse<Complex> > >);
       
@@ -2619,7 +2709,9 @@ void f_init_lgparallele()
       TheOperators->Add("<-", 
 			new OneOperator2_<KN<MPI_Request> *,KN<MPI_Request> *,long>(&set_init0)
 			);
-      atype<KN<MPI_Request>* >()->Add("[","",new OneOperator2_<fMPI_Request*,KN<MPI_Request>*,long >(get_elementp_));    
+      atype<KN<MPI_Request>* >()->Add("[","",new OneOperator2_<fMPI_Request*,KN<MPI_Request>*,long >(get_elementp_));
+      
+       Global.Add("splitComm", "(", new splitComm);
       
   }
 
